@@ -1,3 +1,19 @@
+#
+#   Copyright 2007-2017 The OpenMx Project
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+# 
+#        http://www.apache.org/licenses/LICENSE-2.0
+# 
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
+
+
 ##############################################################################
 # Stable Trait, Autoregressive Trait, State Model with Multiple Indicators  ##
 #                                                                           ##  
@@ -249,6 +265,11 @@ STARTSM <- mxModel("STARTS",
                   matrixStability,
                   algebraSTARTS,
                   stationarityConstraint,
-                  correlatedResiduals)
+                  correlatedResiduals,
+		  mxFitFunctionML(rowwiseParallel=FALSE))
 startsModel <- mxRun(STARTSM)
-omxCheckCloseEnough(startsModel$output$fit, 2718.410, .05)
+omxCheckCloseEnough(startsModel$output$fit, 2718.410, .1)
+
+if (.Platform$OS.type != 'windows' && detectCores() > 1) {
+	omxCheckTrue(startsModel$compute$steps[['GD']]$output$maxThreads > 1)
+}
