@@ -247,7 +247,7 @@ void omxComputeNumericDeriv::doHessianCalculation(int numChildren, struct hess_s
 			omxEstimateHessianOnDiagonal(i, hess_work + threadId);
 		}
 
-		Global->reportProgress("MxComputeNumericDeriv", hess_work->fc);
+		reportProgress(hess_work->fc);
 
 #pragma omp parallel for num_threads(parallelism)
 		for(int i = 0; i < int(todo.size()); i++) {
@@ -256,12 +256,12 @@ void omxComputeNumericDeriv::doHessianCalculation(int numChildren, struct hess_s
 		}
 	} else {
 		for(int i = 0; i < numParams; i++) {
-			Global->reportProgress("MxComputeNumericDeriv", hess_work->fc);
+			reportProgress(hess_work->fc);
 			if (hessian && std::isfinite(hessian[i*numParams + i])) continue;
 			omxEstimateHessianOnDiagonal(i, hess_work);
 		}
 		for(int i = 0; i < int(todo.size()); i++) {
-			Global->reportProgress("MxComputeNumericDeriv", hess_work->fc);
+			reportProgress(hess_work->fc);
 			omxEstimateHessianOffDiagonal(todo[i].first, todo[i].second, hess_work);
 		}
 	}
@@ -331,6 +331,7 @@ void omxComputeNumericDeriv::initFromFrontend(omxState *state, SEXP rObj)
 		}
 	}
 
+	numParams = 0;
 	totalProbeCount = 0;
 	detail = 0;
 }
